@@ -2,13 +2,13 @@
 .onLoad <- function(libname, pkgname, ...) {
 
   if ("knitr" %in% loadedNamespaces()) {
-    knitr::opts_chunk$set(fig.showtext = TRUE)
+    set_fig_showtext()
   }
 
   setHook(
     packageEvent("knitr", "onLoad"),
     function(...) {
-      knitr::opts_chunk$set(fig.showtext = TRUE)
+      set_fig_showtext()
     }
   )
 
